import pandas as pd
import numpy as np
import datetime
import os
import re

from config import Config


class PicarroProvider:

    def __init__(self, config: Config):
        self.picarro_id = config.read("DATA_SOURCE", "picarro_id")
        self.root_dir = config.read("DATA_SOURCE", "picarro_root_dir") + "/"\
                        + self.picarro_id + "/"


    def get_df(self, first_datetime: datetime.datetime, last_datetime: datetime.datetime, columns: list):
        if (first_datetime.year == last_datetime.year) \
                & (first_datetime.month == last_datetime.month) \
                & (first_datetime.day == last_datetime.day):
            directory = self.root_dir + str(first_datetime.year)\
                        + "/" + str(first_datetime.month).zfill(2)\
                        + "/" + str(first_datetime.day).zfill(2)
            filenames = os.listdir(directory)

            # TODO: Read only the relevant files, not all the files of the day.
            # filenames_df = pd.DataFrame({"filename": filenames})
            # filenames_df["datetime"] = [re.search("^" + self.picarro_id + "-" + '([0-9]{8}-[0-9]{6}Z)' + '-DataLog_User.dat$', filename).group(1) for filename in filenames]
            # filenames_df["datetime"] = pd.to_datetime(filenames_df["datetime"])

            picarro_df = pd.DataFrame()
            for filename in filenames:
                step_df = pd.read_csv(directory + "/" + filename, delim_whitespace=True)
                step_df = step_df[["DATE", "TIME"] + columns]
                picarro_df = picarro_df.append(step_df)

            picarro_df["datetime"] = pd.to_datetime(picarro_df["DATE"] + " " + picarro_df["TIME"]).dt.tz_localize('UTC')
            picarro_df = picarro_df.drop(columns=["DATE", "TIME"])
            picarro_df = picarro_df[(picarro_df["datetime"] >= first_datetime) & (picarro_df["datetime"] <= last_datetime)]

            picarro_df = picarro_df.sort_values(by=['datetime'])

            return picarro_df

