import pandas as pd
import numpy as np
import datetime
import os
import re

import utils
from config import Config


class PumpCalibProvider:

    def __init__(self, pump_id: str, config: Config):
        self.pump_id = pump_id
        self.data_dir = config.read("DATA_SOURCE", "absolute_root_dir") + "/pump_calibration/" + pump_id + "/"

        # Get all files in Pump's calib data directory
        self.all_files = os.listdir(self.data_dir)

    def get_runs_df(self) -> pd.DataFrame:
        # Keep only runs-related files (like: 20191010-064649_COLPUMP_calib_runs.csv)
        regex = re.compile(r'^[0-9]{8}-[0-9]{6}_' + self.pump_id + '_calib_runs.csv$')
        runs_files = list(filter(regex.search, self.all_files))

        runs_df = pd.DataFrame()
        calib_id_int = 0
        for filename in runs_files:
            df = pd.read_csv(filepath_or_buffer=self.data_dir + filename,
                             sep=",",
                             parse_dates=["start_time", "end_time"])
            df["start_time"] = df["start_time"].dt.tz_localize('UTC')
            df["end_time"] = df["end_time"].dt.tz_localize('UTC')
            df["calib_id_str"] = df["start_time"].iloc[0].strftime("%Y%m%d-%H%M")
            df["calib_id_int"] = calib_id_int
            calib_id_int += 1
            runs_df = runs_df.append(df)

        return runs_df

    def get_coef_df(self) -> pd.DataFrame:
        df = pd.read_csv(filepath_or_buffer=self.data_dir + "COLPUMP_calib_coef.csv",
                         sep=",",
                         parse_dates=["first_run_datetime", "apply_datetime"])
        df["first_run_datetime"] = df["first_run_datetime"].dt.tz_localize('UTC')
        df["apply_datetime"] = df["apply_datetime"].dt.tz_localize('UTC')
        df["calib_id_str"] = df["first_run_datetime"].dt.strftime("%Y%m%d-%H%M")
        df["calib_id_int"] = df.index
        return df
