#!../venv/bin/python3.7
import sys
from PyQt5.QtWidgets import QApplication
from PyQt5.QtCore import QThread

from config import Config

from gui.mainwindow import MainWindow

from dataprovider.conductcalibprovider import ConductCalibProvider
from dataprovider.exploprovider import ExploProvider
from dataprovider.picarroprovider import PicarroProvider
from dataprovider.pumpcalibprovider import PumpCalibProvider

from uim.conductcalibuim import ConductCalibUim
from uim.explouim import ExploUim
from uim.pumpcalibuim import PumpCalibUim

########################################################################################################################
# CONFIG
########################################################################################################################
config = Config("settings.ini")

########################################################################################################################
# WINDOWS
########################################################################################################################

app = QApplication(sys.argv)
main_window = MainWindow()
main_window_ui = main_window.main_ui

########################################################################################################################
# DATA PROVIDERS
########################################################################################################################
conduct_prvd = ConductCalibProvider()
picarro_prvd = PicarroProvider(config)
explo_prvd = ExploProvider(picarro_prvd)
compump_prvd = PumpCalibProvider("COMPUMP", config)
colpump_prvd = PumpCalibProvider("COLPUMP", config)
picpump_prvd = PumpCalibProvider("PICPUMP", config)

########################################################################################################################
# GUI MANAGERS
########################################################################################################################

conductcalib_uim = ConductCalibUim(conduct_prvd, main_window_ui, config)
explo_uim = ExploUim(explo_prvd, main_window_ui, config)
pump_uim = PumpCalibUim(compump_prvd, colpump_prvd, picpump_prvd, main_window_ui, config)

########################################################################################################################
# LAUNCH APPLICATION
########################################################################################################################

main_window.show()
sys.exit(app.exec_())
