import pyqtgraph as pg
import datetime
import pandas as pd
import numpy as np
import re
from PyQt5.QtWidgets import QTableWidget
from PyQt5.QtGui import QColor

datetime_format = "%Y-%m-%dT%H:%M:%S.%fZ"

def pd_time_to_epoch_ms(series: pd.Series) -> list:
    """Convert a Pandas' Series containing Timestamp data into 1D array containing seconds (as float) since epoch."""
    # Pandas' Timestamp data are in nanoseconds.
    return list(pd.to_datetime(series).astype(np.int64) / 1e9)


def datetime64_to_epoch_ms(datetimes_list: np.ndarray) -> list:
    return [float(instant) / 1e9 for instant in datetimes_list]


def convert_to_numeric(str_value: str):
    """Convert a string to float (if there is a "." in the string) or to integer, if possible."""
    if re.match("^-?\d+\.\d+$", str_value):
        return float(str_value)
    elif re.match("^-?\d+$", str_value):
        return int(str_value)
    else:
        return str_value

####################################################################
# Graphics

class TimeAxisItem(pg.AxisItem):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        # self.setLabel(text='Time', units=None)
        self.enableAutoSIPrefix(False)

    def tickStrings(self, values, scale, spacing):
        try:
            tick_strings = [datetime.datetime.fromtimestamp(value, tz=datetime.timezone.utc).strftime("%H:%M:%S") for value in values]
        except ValueError:
            tick_strings = ["ERROR" for value in values]
        return tick_strings


def highlight_row(table: QTableWidget, highlighted_row_id: int,
                  highlighted_row_color: QColor = QColor(173, 216, 230),
                  other_rows_color: QColor = QColor(255, 255, 255)) -> None:
    """Highlight a table's row by changing its background color.

    Parameters
    ----------
    table: PyQt5.QtWidgets.QTableWidget
        Table whose row should be highlighted.
    highlighted_row_id: int
        Index (first row is 0) of the row which should be highlighted.
    highlighted_row_color: PyQt5.QtGui.QColor
        Background color of the highlighted row. Default is light blue.
    other_rows_color: PyQt5.QtGui.QColor
        Background color of the other rows of the table. Default is white.

    Returns
    -------
        Nothing, modify the input ``table``
    """
    for row_id in range(table.rowCount()):
        if row_id == highlighted_row_id:
            row_color = highlighted_row_color
        else:
            row_color = other_rows_color
        for column_id in range(table.columnCount()):
            table.item(row_id, column_id).setBackground(row_color)